/*******************************************************************************
Copyright (c) 2000 Oracle Corporation

File        : lovLib.js

Author      : Jan Kettenis

Notes       : This library contains functions that support LOV's.

Open Issues :

$revision_history$
05-mei-2004   Steven Davelaar
  1.0         

07-mar-2003   Jan Kettenis
  1.0         Initial creation by pasting JavaScript functions out of
              lovpageFrame.js. Thereby:
              - added doClear() to support LOV form
              - added parameters to doAccept to make it more generic
              - formatted JavaScript
******************************************************************************/
/*
$add_to_revision_history
$
*/

/**
 * returnValueValue is the actual value that is returned by the LOV, for
 * example the Id
 */
var returnValueValue;
/**
 * returnDisplayValue is the displayed or descriptor value that corresponds with
 * returnValueValue
 */
var returnDisplayValue;

/**
 * doCancel closes the LOV without selecting a value.
 * @return: false
 */
function doCancel()
{
	top.returnDisplayValue = (void 0);
	top.returnValueValue = (void 0);
	top.close();

	return false;
} // doCancel


/**
 * doAccept checks if a value has been selected. If not, an error message
 * is given. Otherwise the selected value is returned to the calling form
 * and the LOV form closes
 * @formName: the name of the LOV form
 * @tableName: the name of the LOV table
 * @valueItemName: the name of the item that contains the actual value to return
 * @displayItemName: the name of the item that contains the displayed descriptor value
 *                   and that corresponds with the valueItemName
 * @return: false
 */
function doAccept(formName, tableName, valueItemName, displayItemName)
{
	var form             = lovpage.document.forms[formName];
	// selectItem is the item that the user checks to select a value from the LOV
  var selectItem       = form[tableName+":selected"];
  // the default -1 for selectedRowIndex indicates that no value has been selected (yet)
	var selectedRowIndex = -1;

	// check if only one row displayed; if so then selectItem.length is undefined
	// and we need to use selectItem.checked to see if that row is selected or not.
	if (selectItem.length)
	{
		for (var i = 0 ; i < selectItem.length ; i++)
		{
			// alert (selectItem[i].checked);
			if (selectItem[i].checked)
			{
				selectedRowIndex = i;
			}
		}
	}
	else
	{
		selectedRowIndex = (selectItem.checked) ? 0 : -1;
	}

	if (selectedRowIndex < 0)
	{
		// OK is pressed, but no value has been selected
		alert("Please select a row");
		return false;
	}

	valueItem   = form[tableName+":"+valueItemName+":"+selectedRowIndex];
	displayItem = form[tableName+":"+displayItemName+":"+selectedRowIndex];

	top.returnValueValue   = valueItem.value;
	top.returnDisplayValue = displayItem.value;
	close();

	return false;
} // doAccept


/**
 * doClear clears the LOV item in the calling form, and closes the LOV form
 * without selecting a value
 * @return: false
 */
function doClear()
{
	top.returnDisplayValue = '';
	top.returnValueValue = '';
	top.close();

	return false;
}  // doClear


/**
 * validateSearchCriterium checks if the user has entered a specified minimum number of
 * characters as search criterium
 * @searchItem: the item that is used to search with
 * @minimumSearchLength: the minimum number of characters to use
 * @return: false
 */
function validateSearchCriterium(searchItem, minimumSearchLength)
{
	if (searchItem.length < minimumSearchLength)
	{
	 alert (getMessage("searchCriterium",[minimumSearchLength]));
	}
  return false;
} // validateSearchCriterium
