
CREATE TABLE COMPANIES
(
  ID    NUMBER                                  NOT NULL,
  NAME  VARCHAR2(25 BYTE)                       NOT NULL
)
LOGGING 
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE LISTS
(
  ID    NUMBER                                  NOT NULL,
  NAME  VARCHAR2(20 BYTE)                       NOT NULL
)
LOGGING 
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE LIST_ENTRIES
(
  ID      NUMBER                                NOT NULL,
  LIT_ID  NUMBER                                NOT NULL,
  CPY_ID  NUMBER,
  PSN_ID  NUMBER
)
LOGGING 
NOCACHE
NOPARALLEL
MONITORING;


CREATE TABLE PERSONS
(
  ID      NUMBER                                NOT NULL,
  NAME    VARCHAR2(30 BYTE)                     NOT NULL,
  CPY_ID  NUMBER
)
LOGGING 
NOCACHE
NOPARALLEL
MONITORING;


create sequence general_seq
/


CREATE OR REPLACE TRIGGER CPY_BRI BEFORE INSERT ON COMPANIES
REFERENCING OLD AS OLD NEW AS NEW
FOR EACH ROW
BEGIN
  if :new.id is null
  then
    select general_seq.nextval
    into   :new.id
    from   dual
    ;
  end if;
END;
/
SHOW ERRORS;



CREATE OR REPLACE TRIGGER LIE_BRI BEFORE INSERT ON LIST_ENTRIES
REFERENCING OLD AS OLD NEW AS NEW
FOR EACH ROW
BEGIN
  if :new.id is null
  then
    select general_seq.nextval
    into   :new.id
    from   dual
    ;
  end if;
END;
/
SHOW ERRORS;



CREATE OR REPLACE TRIGGER LIT_BRI BEFORE INSERT ON LISTS
REFERENCING OLD AS OLD NEW AS NEW
FOR EACH ROW
BEGIN
  if :new.id is null
  then
    select general_seq.nextval
    into   :new.id
    from   dual
    ;
  end if;
END;
/
SHOW ERRORS;



CREATE OR REPLACE TRIGGER PSN_BRI BEFORE INSERT ON PERSONS
REFERENCING OLD AS OLD NEW AS NEW
FOR EACH ROW
BEGIN
  if :new.id is null
  then
    select general_seq.nextval
    into   :new.id
    from   dual
    ;
  end if;
END;
/
SHOW ERRORS;



ALTER TABLE COMPANIES ADD (
  CONSTRAINT COMPANIES_PK1 PRIMARY KEY (ID));


ALTER TABLE LISTS ADD (
  CONSTRAINT LISTS_PK1 PRIMARY KEY (ID));


ALTER TABLE LIST_ENTRIES ADD (
  CONSTRAINT LIST_ENTRIES_PK1 PRIMARY KEY (ID));


ALTER TABLE PERSONS ADD (
  CONSTRAINT PERSONS_PK1 PRIMARY KEY (ID));


ALTER TABLE LIST_ENTRIES ADD (
  CONSTRAINT LIE_CPY_FK1 FOREIGN KEY (CPY_ID) 
    REFERENCES COMPANIES (ID));

ALTER TABLE LIST_ENTRIES ADD (
  CONSTRAINT LIE_LIT_FK1 FOREIGN KEY (LIT_ID) 
    REFERENCES LISTS (ID));

ALTER TABLE LIST_ENTRIES ADD (
  CONSTRAINT LIE_PSN_FK2 FOREIGN KEY (PSN_ID) 
    REFERENCES PERSONS (ID));


ALTER TABLE PERSONS ADD (
  CONSTRAINT PSN_CPY_FK1 FOREIGN KEY (CPY_ID) 
    REFERENCES COMPANIES (ID));



INSERT INTO COMPANIES ( ID, NAME ) VALUES ( 
1, 'AMIS'); 
INSERT INTO COMPANIES ( ID, NAME ) VALUES ( 
2, 'Oracle'); 
INSERT INTO COMPANIES ( ID, NAME ) VALUES ( 
3, 'Min V & W'); 
commit;
 
INSERT INTO LISTS ( ID, NAME ) VALUES ( 
11, 'ChristmasPartyInvite'); 
commit;
 
INSERT INTO LIST_ENTRIES ( ID, LIT_ID, CPY_ID, PSN_ID ) VALUES ( 
13, 11, NULL, 5); 
INSERT INTO LIST_ENTRIES ( ID, LIT_ID, CPY_ID, PSN_ID ) VALUES ( 
15, 11, 1, NULL); 
INSERT INTO LIST_ENTRIES ( ID, LIT_ID, CPY_ID, PSN_ID ) VALUES ( 
16, 11, 2, NULL); 
INSERT INTO LIST_ENTRIES ( ID, LIT_ID, CPY_ID, PSN_ID ) VALUES ( 
17, 11, NULL, 10); 
INSERT INTO LIST_ENTRIES ( ID, LIT_ID, CPY_ID, PSN_ID ) VALUES ( 
18, 11, NULL, 8); 
INSERT INTO LIST_ENTRIES ( ID, LIT_ID, CPY_ID, PSN_ID ) VALUES ( 
19, 11, NULL, 6); 
commit;
 
INSERT INTO PERSONS ( ID, NAME, CPY_ID ) VALUES ( 
4, 'Steven Davelaar', 2); 
INSERT INTO PERSONS ( ID, NAME, CPY_ID ) VALUES ( 
5, 'Lucas Jellema', 1); 
INSERT INTO PERSONS ( ID, NAME, CPY_ID ) VALUES ( 
6, 'Wouter van Reeven', 1); 
INSERT INTO PERSONS ( ID, NAME, CPY_ID ) VALUES ( 
7, 'Ton van Kooten', 2); 
INSERT INTO PERSONS ( ID, NAME, CPY_ID ) VALUES ( 
8, 'Madelon van Rossum', 3); 
INSERT INTO PERSONS ( ID, NAME, CPY_ID ) VALUES ( 
9, 'Peter Ebell', 2); 
INSERT INTO PERSONS ( ID, NAME, CPY_ID ) VALUES ( 
10, 'Frank Terburg', 1); 
commit;
 
